"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MathJax3Renderer = exports.Mathjax2Renderer = void 0;
const model_1 = require("./model");
const lodash_es_1 = require("lodash-es");
const load_script_css_1 = require("@cnblogs/load-script-css");
class Mathjax2Renderer {
    constructor() {
        this._defaultConfig = model_1.defaultConfig[model_1.MathEngine.MathJax2];
        this._defaultMathJaxConfig = {
            tex2jax: {
                inlineMath: [
                    ['$', '$'],
                    ['\\(', '\\)'],
                ],
                processClass: 'math',
                processEscapes: true,
            },
            TeX: {
                equationNumbers: {
                    autoNumber: 'AMS',
                    useLabelIds: true,
                },
                extensions: ['extpfeil.js', 'mediawiki-texvc.js'],
                Macros: { bm: '\\boldsymbol' },
            },
            'HTML-CSS': { linebreaks: { automatic: true } },
            SVG: { linebreaks: { automatic: true } },
            skipStartupTypeset: true,
        };
        this._config = this._defaultConfig;
    }
    get _global() {
        var _a;
        return ((_a = this._config.document.defaultView) !== null && _a !== void 0 ? _a : window);
    }
    render(container, callback) {
        if (!this._config.isEnabled)
            return Promise.resolve();
        return this.init()
            .then(mathjax => {
            if (!mathjax)
                return;
            const { onRendered } = this._config;
            mathjax.Hub.Queue(['Typeset', mathjax.Hub, container]);
            if (onRendered != null) {
                mathjax.Hub.Queue(() => onRendered(mathjax));
            }
            if (callback) {
                mathjax.Hub.Queue(callback);
            }
        })
            .catch(console.warn);
    }
    config(value) {
        this._config = (0, lodash_es_1.merge)({}, this._defaultConfig, value);
        return this;
    }
    init() {
        if (this._initTask)
            return this._initTask;
        const { entryScript, tapMathJaxConfig, document } = this._config;
        return (this._initTask = (0, load_script_css_1.loadScript)({
            src: entryScript,
            id: 'mathjax',
            timeoutSeconds: 10,
            appendTo: document.head,
        })
            .then(() => {
            var _a;
            const { MathJax } = this._global;
            if (MathJax) {
                MathJax.Hub.Config((_a = tapMathJaxConfig === null || tapMathJaxConfig === void 0 ? void 0 : tapMathJaxConfig.call(undefined, Object.assign({}, this._defaultMathJaxConfig))) !== null && _a !== void 0 ? _a : Object.assign({}, this._defaultMathJaxConfig));
                MathJax.Hub.Configured();
                return MathJax;
            }
        })
            .catch(() => (this._initTask = undefined)));
    }
}
exports.Mathjax2Renderer = Mathjax2Renderer;
class MathJax3Renderer {
    constructor() {
        this._defaultConfig = model_1.defaultConfig[model_1.MathEngine.MathJax3];
        this._defaultMathJaxConfig = {
            tex: {
                inlineMath: [
                    ['$', '$'],
                    ['\\(', '\\)'],
                ],
                processEscapes: true,
                tags: 'ams',
                useLabelIds: true,
                macros: {
                    bm: '\\boldsymbol',
                },
                packages: { '[+]': ['noerrors', 'extpfeil'] },
            },
            options: {
                processHtmlClass: 'math',
                ignoreHtmlClass: 'tex2jax_ignore',
            },
            loader: {
                load: ['[tex]/noerrors', '[tex]/extpfeil'],
            },
            startup: {
                typeset: false,
            },
        };
        this._config = this._defaultConfig;
    }
    config(value) {
        this._config = (0, lodash_es_1.merge)({}, this._defaultConfig, value);
        return this;
    }
    render(container, callback) {
        if (!this._config.isEnabled)
            return Promise.resolve();
        return this.init()
            .then(mathjax => {
            mathjax
                ? (mathjax.startup.promise = mathjax.startup.promise.then(() => mathjax.typesetPromise([container]).then(() => {
                    var _a;
                    try {
                        (_a = this._config.onRendered) === null || _a === void 0 ? void 0 : _a.call(undefined, mathjax);
                    }
                    catch (e) {
                        console.error(e);
                    }
                    try {
                        callback === null || callback === void 0 ? void 0 : callback.call(undefined);
                    }
                    catch (e) {
                        console.error(e);
                    }
                })))
                : undefined;
        })
            .catch(console.warn);
    }
    init() {
        var _a;
        return ((_a = this._initTask) !== null && _a !== void 0 ? _a : (this._initTask = new Promise((resolve, reject) => {
            var _a, _b;
            const { entryScript, tapMathJaxConfig, document: _document } = this._config;
            const _window = ((_a = _document.defaultView) !== null && _a !== void 0 ? _a : window);
            _window.MathJax = (_b = tapMathJaxConfig === null || tapMathJaxConfig === void 0 ? void 0 : tapMathJaxConfig.call(undefined, Object.assign({}, this._defaultMathJaxConfig))) !== null && _b !== void 0 ? _b : Object.assign({}, this._defaultMathJaxConfig);
            if (!_window.MathJax.startup) {
                _window.MathJax.startup = {};
            }
            _window.MathJax.startup.ready = () => {
                var _a, _b;
                (_b = (_a = _window.MathJax) === null || _a === void 0 ? void 0 : _a.startup) === null || _b === void 0 ? void 0 : _b.defaultReady();
                resolve(_window.MathJax);
            };
            (0, load_script_css_1.loadScript)({
                src: entryScript,
                id: 'mathjax',
                executionStrategy: 'defer',
                appendTo: _window.document.head,
            }).catch(reject);
        }))).catch(() => (this._initTask = undefined));
    }
}
exports.MathJax3Renderer = MathJax3Renderer;
//# sourceMappingURL=impl.js.map