/// <reference types="mathjax2" />
import { MathJaxObject as StartupObject, MathJaxConfig as MJStartupConfig } from 'mathjax-full/js/components/startup';
export declare type MathJaxConfig = MJStartupConfig & {
    tex: Record<string, unknown>;
    [name: string]: unknown;
};
export declare interface MathJaxObject {
    config: MathJaxConfig;
    startup: StartupObject['startup'];
    typeset(arg: unknown[]): void;
    typesetPromise(arg: unknown[]): Promise<void>;
}
export declare enum MathEngine {
    MathJax2 = 0,
    MathJax3 = 1
}
export interface RendererConfig<TEngine extends MathEngine> {
    engine: MathEngine;
    entryScript: string;
    document: Document;
    isEnabled: boolean;
    onRendered?: (mathjax: TEngine extends MathEngine.MathJax2 ? typeof MathJax : MathJaxObject) => void | Promise<void>;
    tapMathJaxConfig?: <TConfig = TEngine extends MathEngine.MathJax2 ? MathJax.Config : MathJaxConfig>(config: TConfig) => TConfig;
}
export declare type MathJax2RendererConfig = RendererConfig<MathEngine.MathJax2> & {
    engine: MathEngine.MathJax2;
};
export declare type MathJax3RendererConfig = RendererConfig<MathEngine.MathJax3> & {
    engine: MathEngine.MathJax3;
};
export declare const defaultConfig: {
    [MathEngine.MathJax2]: MathJax2RendererConfig;
    [MathEngine.MathJax3]: MathJax3RendererConfig;
};
export interface IMathRenderer<TEngine extends MathEngine> {
    config(value: Partial<RendererConfig<TEngine>>): this;
    render(container: HTMLElement, callback?: () => unknown): Promise<void>;
}
